==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/javascript/TypeScriptJsxMode.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) Determines how JSX should get transformed into valid JavaScript.
 * <p>
 * @see https://www.typescriptlang.org/docs/handbook/jsx.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.890Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.TypeScriptJsxMode")
public enum TypeScriptJsxMode {
    /**
     * (experimental) Keeps the JSX as part of the output to be further consumed by another transform step (e.g. Babel).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    PRESERVE,
    /**
     * (experimental) Converts JSX syntax into React.createElement, does not need to go through a JSX transformation before use, and the output will have a .js file extension.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    REACT,
    /**
     * (experimental) Keeps all JSX like 'preserve' mode, but output will have a .js extension.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    REACT_NATIVE,
    /**
     * (experimental) Passes `key` separately from props and always passes `children` as props (since React 17).
     * <p>
     * @see https://www.typescriptlang.org/docs/handbook/release-notes/typescript-4-1.html#react-17-jsx-factories
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    REACT_JSX,
    /**
     * (experimental) Same as `REACT_JSX` with additional debug data.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    REACT_JSXDEV,
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/javascript/TypeScriptJsxMode.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) Determines how JSX should get transformed into valid JavaScript.
 * <p>
 * @see <a href="https://www.typescriptlang.org/docs/handbook/jsx.html">https://www.typescriptlang.org/docs/handbook/jsx.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.548Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.TypeScriptJsxMode")
public enum TypeScriptJsxMode {
    /**
     * (experimental) Keeps the JSX as part of the output to be further consumed by another transform step (e.g. Babel).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    PRESERVE,
    /**
     * (experimental) Converts JSX syntax into React.createElement, does not need to go through a JSX transformation before use, and the output will have a .js file extension.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    REACT,
    /**
     * (experimental) Keeps all JSX like 'preserve' mode, but output will have a .js extension.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    REACT_NATIVE,
    /**
     * (experimental) Passes <code>key</code> separately from props and always passes <code>children</code> as props (since React 17).
     * <p>
     * @see <a href="https://www.typescriptlang.org/docs/handbook/release-notes/typescript-4-1.html#react-17-jsx-factories">https://www.typescriptlang.org/docs/handbook/release-notes/typescript-4-1.html#react-17-jsx-factories</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    REACT_JSX,
    /**
     * (experimental) Same as <code>REACT_JSX</code> with additional debug data.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    REACT_JSXDEV,
}
